eppo library

Classes

AssignmentCache
Interface for an assignment cache
AssignmentEvent
Represents an event for logging an assignment
AssignmentLogger
Interface for logging assignment events
BanditEvaluation
Represents the details of an assignment, including variation, action, and evaluation details
BanditEvent
BanditLogger
Interface for logging bandit events
ClientConfiguration
ContextAttributes
Context attributes with numeric and categorical attributes
Eppo
The main interface to interact with the Eppo SDK.
EppoPrecomputedClient
Client for evaluating precomputed feature flags and bandits
InMemoryAssignmentCache
A cache that never expires.
NoOpAssignmentCache
No-op implementation of the assignment cache that disables caching
Subject
Subject information for flag evaluation
SubjectEvaluation
Options for creating a precomputed client

Enums

SdkPlatform
Supported SDK platforms