removeSubject static method

void removeSubject(
  1. String subjectKey
)

Removes an SDK instance for a specific subject key.

This is useful for cleanup when a user logs out or is no longer active.

Parameters:

  • subjectKey: The unique identifier for the subject to remove.

Example:

// When user logs out
Eppo.removeSubject('user-456');

Implementation

static void removeSubject(String subjectKey) {
  _instances.remove(subjectKey);
  // If this was the singleton subject, clear the singleton reference
  if (_singletonSubjectKey == subjectKey) {
    _singletonSubjectKey = null;
  }
}