Subject class

Subject information for flag evaluation

Constructors

Subject({required String subjectKey, ContextAttributes? subjectAttributes})
Creates a new subject
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjectAttributes ContextAttributes?
The subject attributes
final
subjectKey String
The subject key
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited