Eppo class
The main interface to interact with the Eppo SDK.
Eppo is a feature flagging and experimentation platform that allows you to control feature rollouts and run A/B tests in your application.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
activeSubjects
→ List<
String> -
Gets all active subject keys that have SDK instances.
no setter
- instance → EppoPrecomputedClient?
-
Gets the current client instance.
no setter
Static Methods
-
forSubject(
SubjectEvaluation subjectEvaluation) → Future< EppoPrecomputedClient> - Gets or creates an SDK instance for a specific subject.
-
getBanditAction(
String flagKey, String defaultValue) → BanditEvaluation - Gets a bandit action for the specified flag.
-
getBooleanAssignment(
String flagKey, bool defaultValue) → bool - Gets a boolean assignment for the specified flag.
-
getIntegerAssignment(
String flagKey, int defaultValue) → int - Gets an integer assignment for the specified flag.
-
getJSONAssignment(
String flagKey, Map< String, dynamic> defaultValue) → Map<String, dynamic> - Gets a JSON assignment for the specified flag.
-
getNumericAssignment(
String flagKey, double defaultValue) → double - Gets a numeric (double) assignment for the specified flag.
-
getStringAssignment(
String flagKey, String defaultValue) → String - Gets a string assignment for the specified flag.
-
initialize(
String sdkKey, SubjectEvaluation subjectEvaluation, ClientConfiguration clientConfiguration) → Future< void> - Initializes the Eppo SDK with the provided configuration.
-
removeSubject(
String subjectKey) → void - Removes an SDK instance for a specific subject key.
-
reset(
) → void - Resets the SDK to an uninitialized state.